# Orthographic Projector
#### A Rust-based Python library for generating orthographic projections from point clouds.

## Prerequisites
- Python 3.10 or later
- rustc 1.77.2 or later
- pip

## Setup
### From PyPI
```bash
pip install orthographic_projector
# or
python -m pip install orthographic_projector
```

### From source
```bash
# Clone this repository
https://github.com/akaTsunemori/orthographic_projector.git

# cd into the project folder
cd orthographic_projector

# Setup a virtual environment
python -m venv venv

# Activate the virtual environment
source ./venv/bin/activate

# Install the prerequisites
pip install -r requirements.txt
```

## Usage
An example of the usage is provided in [examples/example_generate_projections.py](examples/example_generate_projections.py).

## Contributing
Contributions are what make the open-source community such an amazing place to learn, inspire, and create. Any contributions you make are greatly appreciated, you can simply open an issue.

## License
GNU GENERAL PUBLIC LICENSE
Version 2, June 1991

---

> GitHub [@akaTsunemori](https://github.com/akaTsunemori)
